@@ -61,6 +61,7 @@ class LocalValidityMixin:
 
         Examples
         --------
+        >>> from logics.utils.parsers import classical_parser
         >>> from logics.instances.propositional.many_valued_semantics import classical_mvl_semantics as CL, ST_mvl_semantics as ST
         >>> CL.is_locally_valid(classical_parser.parse('p or not p'))
         True
@@ -99,6 +100,7 @@ class LocalValidityMixin:
 
         Examples
         --------
+        >>> from logics.utils.parsers import classical_parser
         >>> from logics.instances.propositional.many_valued_semantics import classical_mvl_semantics as CL
         >>> CL.is_locally_antivalid(classical_parser.parse('q, p then q / p'))
         False
@@ -118,6 +120,7 @@ class LocalValidityMixin:
 
         Examples
         --------
+        >>> from logics.utils.parsers import classical_parser
         >>> from logics.instances.propositional.many_valued_semantics import classical_mvl_semantics as CL
         >>> CL.is_contingent(classical_parser.parse('p'))
         True
@@ -364,11 +367,12 @@ class MixedManyValuedSemantics(LocalValidityMixin, ValidityShortcutsMixin):
 
         # If it is not a callable but is an indexable
         else:
-            args = tuple(self.truth_values.index(x) for x in args)  # e.g. if values is [1, 0], (0, 1) turns into (1, 0)
+            args = tuple(self.truth_values.index(x) for x in args)
+            # e.g. if values is ['1', '0'], ('0', '1') turns into (1, 0) -the indexes
             truth_table = copy(self.truth_function_dict[constant])
             for value_index in args:
-                # If the tt is [[1, 1], [1, 0]] for the values [1, 0], calling with (0, 0) first turns into (1, 1) above
-                # and then we get [1, 0] in the first run through this loop, and 0 in the second run
+                # If the tt is [[1, 1], [1, 0]] for the values [1, 0], calling with ('0', '0') first turns into (1, 1)
+                # above, and then we get [1, 0] in the first run through this loop, and 0 in the second run
                 truth_table = truth_table[value_index]
             return truth_table
 
@@ -390,8 +394,8 @@ class MixedManyValuedSemantics(LocalValidityMixin, ValidityShortcutsMixin):
 
         Examples
         --------
-        >>> from logics.instances.propositional.many_valued_semantics import classical_mvl_semantics as CL, ST_mvl_semantics as ST
         >>> from logics.utils.parsers import classical_parser
+        >>> from logics.instances.propositional.many_valued_semantics import classical_mvl_semantics as CL, ST_mvl_semantics as ST
         >>> CL.valuation(classical_parser.parse('p'), {'p': '1'})
         '1'
         >>> CL.valuation(classical_parser.parse('p then q'), {'p': '1'})
@@ -521,8 +525,8 @@ class MixedManyValuedSemantics(LocalValidityMixin, ValidityShortcutsMixin):
 
         Examples
         --------
-        >>> from logics.instances.propositional.many_valued_semantics import classical_mvl_semantics as CL, ST_mvl_semantics as ST
         >>> from logics.utils.parsers import classical_parser
+        >>> from logics.instances.propositional.many_valued_semantics import classical_mvl_semantics as CL, ST_mvl_semantics as ST
         >>> CL.satisfies(classical_parser.parse('p'), {'p': '1'})
         True
         >>> ST.satisfies(classical_parser.parse('p'), {'p': 'i'})
@@ -589,6 +593,7 @@ class MixedManyValuedSemantics(LocalValidityMixin, ValidityShortcutsMixin):
 
         Examples
         --------
+        >>> from logics.utils.parsers import classical_parser
         >>> from logics.instances.propositional.many_valued_semantics import classical_mvl_semantics as CL
         >>> CL.is_globally_valid(classical_parser.parse('(p / q) // (r / s)'))
         True
@@ -622,6 +627,7 @@ class MixedManyValuedSemantics(LocalValidityMixin, ValidityShortcutsMixin):
 
         Examples
         --------
+        >>> from logics.utils.parsers import classical_parser
         >>> from logics.instances.propositional.many_valued_semantics import classical_mvl_semantics as CL
         >>> CL.is_globally_valid2(classical_parser.parse('(p / q) // (r / s)'))
         True
@@ -650,6 +656,7 @@ class MixedManyValuedSemantics(LocalValidityMixin, ValidityShortcutsMixin):
 
         Examples
         --------
+        >>> from logics.utils.parsers import classical_parser
         >>> from logics.instances.propositional.many_valued_semantics import classical_mvl_semantics as CL
         >>> CL.is_globally_valid3(classical_parser.parse('(p / q)'))
         True
@@ -667,15 +674,16 @@ class MixedManyValuedSemantics(LocalValidityMixin, ValidityShortcutsMixin):
         # If you got to here, all premises are locally valid and all conclusions locally invalid
         return False
 
-    def truth_table(self, formula):
+    def truth_table(self, formula_or_inference):
         """Returns a representation of a truth table for a formula.
 
-        Takes an instance of Formula as input, and returns 2-list where the first member is a list of subformulae
-        (ordered by depth) and the second member is a 2-dimensional list with the valuations of those subformulae
-        (in that order)
+        Takes an instance of Formula or Inference as input, and returns 2-list where the first member is a list of
+        subformulae (ordered by depth) and the second member is a 2-dimensional list with the valuations of those
+        subformulae (in that order)
 
         Examples
         --------
+        >>> from logics.utils.parsers import classical_parser
         >>> from logics.instances.propositional.many_valued_semantics import classical_mvl_semantics as CL
         >>> CL.truth_table(classical_parser.parse('p'))
         [[['p']], [['1'], ['0']]]
@@ -689,14 +697,30 @@ class MixedManyValuedSemantics(LocalValidityMixin, ValidityShortcutsMixin):
         ['1', '0', '0']
         ['0', '0', '1']
 
-        In each row above, the three values correspond to the values
-        of `p`, `q`, and `p → q` respectively
+        In each row above, the three values correspond to the values of `p`, `q`, and `p → q` respectively.
+        Examples for inferences / metainferences:
+
+        >>> subformulae, table = CL.truth_table(classical_parser.parse('p / p'))
+        [['p']]
+        >>> for row in table:
+        ...     print(row)
+        ['1']
+        ['0']
+        >>> subformulae, table = CL.truth_table(classical_parser.parse('(q / p) // (p / ~q)'))
+        >>> subformulae
+        [['q'], ['p'], ['~', ['q']]]
+        >>> for row in table:
+        ...     print(row)
+        ['1', '1', '0']
+        ['0', '1', '1']
+        ['1', '0', '0']
+        ['0', '0', '1']
         """
-        ordered_subformulae = sorted(formula.subformulae, key=lambda x: x.depth)
-        truth_value_combinations = self._get_truth_value_combinations(formula)
+        ordered_subformulae = sorted(formula_or_inference.subformulae, key=lambda x: x.depth)
+        truth_value_combinations = self._get_truth_value_combinations(formula_or_inference)
         truth_table = list()
         for combination in truth_value_combinations:
-            atomic_valuation_dict = self._get_atomic_valuation_dict(formula, combination)
+            atomic_valuation_dict = self._get_atomic_valuation_dict(formula_or_inference, combination)
             truth_table_row = list()
             for subformula in ordered_subformulae:
                 truth_table_row.append(self.valuation(subformula, atomic_valuation_dict))
